
local MAX_TIME = 2
local MAX_TIME_MAIN = 1.2
local MAX_TIME_RED = 0.6
local explosions = {}

local smallfb, bigfb, chunkfb

function loadExplosions()
	--smallfb = love.graphics.newFramebuffer(20, 20)
	smallfb = love.graphics.newFramebuffer(32, 32)
	
	smallfb:renderTo(function()
		for i=10,1,-1 do --this ensures that we get soft and round particles
			love.graphics.setColor(255, 255, 255, 80)
			love.graphics.circle("fill", 10, 10, i)
		end
	end)
	
	--bigfb = love.graphics.newFramebuffer(30, 30)
	bigfb = love.graphics.newFramebuffer(32, 32)
	
	bigfb:renderTo(function()
		
		for i=13,1,-1 do
			love.graphics.setColor(255, 255, 255, 80+math.random(0,40))
			love.graphics.circle("fill", 15+math.random(-3,3), 15+math.random(-3,3), i)
			
			if math.random()*10 > 6 then
				love.graphics.rectangle("fill", math.random()*25, math.random()*25, math.random()*25, math.random()*25)
			end
			
		end
		
	end)
	
	--chunkfb = love.graphics.newFramebuffer(30, 30)
	chunkfb = love.graphics.newFramebuffer(32, 32)
	
	chunkfb:renderTo(function()
		
		for i=13,1,-1 do
			love.graphics.setColor(255, 255, 255, 240)
			love.graphics.circle("fill", 15+math.random(-3,3), 15+math.random(-3,3), i)
			
			if math.random()*10 > 6 then
				love.graphics.rectangle("fill", math.random()*25, math.random()*25, math.random()*25, math.random()*25)
			end
			
		end
		
	end)
end

function drawExplosions()
	love.graphics.setColorMode("modulate")
	for k,v in ipairs(explosions) do
		love.graphics.setBlendMode("additive")
		love.graphics.setColor(v.tint.r, v.tint.g, v.tint.b, 120 * (1 - (v.time/v.max_time)))
		if v.type == "small" then
			love.graphics.draw(smallfb, v.x, v.y, 0, 1 - (v.time/v.max_time), 1 - (v.time/v.max_time), 10, 10)
		elseif v.type == "big" then
			love.graphics.draw(bigfb, v.x, v.y, v.rotation, 1 - (v.time/v.max_time), 1 - (v.time/v.max_time), 15, 15)
		elseif v.type == "chunk" then
			love.graphics.setBlendMode("alpha")
			love.graphics.draw(chunkfb, v.x, v.y, v.rotation, 1, 1, 15, 15)
		end
	end
end

function updateExplosions(dt)
	
	local e
	for i = #explosions,1,-1 do
		e = explosions[i]
		
		
		e.time = e.time + dt --add time 
		if e.time > e.max_time then --lived for too long, away with you
			table.remove(explosions, i)
		end
	
		e.x = e.x + e.velx
		e.y = e.y + e.vely
		
		e.vely = e.vely + e.gravity
		e.velx = e.velx * e.fricx
		e.vely = e.vely * e.fricy
		
		if e.type == "big" or e.type == "chunk" then
			e.rotation = e.rotation+e.rotvel
			e.rotvel = e.rotvel * e.rotfric
		end
		
	end
	
end

function newExplosion(x,y)

	for i=x-1,x+1,0.5 do
		table.insert(explosions, 
		{x=i+math.random(-1, 1), 
		y=y+math.random(-2.0, 2.0), 
		time=0, 
		max_time=MAX_TIME_MAIN-math.random()+math.random()*2, 
		type="chunk", 
		velx=(x-i)*6,
		vely=-10+math.random()*-10,
		tint={r=79 + math.random(-10, 20), g=36 + math.random(-10, 25), b=18 + math.random(-5, 25)},
		gravity=0.3,
		fricx=0.9+(math.random()*0.08),
		fricy=1,
		rotation=0,
		rotvel=(math.random()*0.5)-math.random(),
		rotfric=0.99
		})
	end

	for i=x-1,x+1,0.01 do
		table.insert(explosions, 
		{x=i+math.random(-1, 1), 
		y=y+math.random(-2.0, 2.0), 
		time=0, 
		max_time=MAX_TIME_MAIN-math.random()+math.random()*2, 
		type="big", 
		velx=(x-i)*6,
		vely=-1.4+math.random()*-(30-math.abs(x-i)*10),
		tint={r=214 + math.random(-10, 20), g=161 + math.random(-10, 25), b=36 + math.random(-5, 25)},
		gravity=0.2,
		fricx=0.9+(math.random()*0.08),
		fricy=0.9,
		rotation=0,
		rotvel=(math.random()*0.5)-math.random(),
		rotfric=0.99
		})
	end
	
	for i=x-1,x+1,0.01 do
		table.insert(explosions, 
		{x=i+math.random(-1, 1), 
		y=y+math.random(-2.0, 2.0), 
		time=0, 
		max_time=MAX_TIME_RED-math.random()*0.3, 
		type="big", 
		velx=(x-i)*3,
		vely=-1.4+math.random()*-(15-math.abs(x-i)*5),
		tint={r=214 + math.random(-10, 20), g=81 + math.random(-10, 25), b=36 + math.random(-5, 25)},
		gravity=0.2,
		fricx=0.9+(math.random()*0.08),
		fricy=0.9,
		rotation=0,
		rotvel=(math.random()*0.5)-math.random(),
		rotfric=0.9
		})
	end

	for i=x-32,x+32,0.1 do
		table.insert(explosions, 
		{x=i+math.random(-0.5, 0.5), 
		y=y+math.random(-5.0, 5.0), 
		time=0, 
		max_time=MAX_TIME-math.random()+math.random()*2, 
		type="small", 
		velx=(x-i)*-(0.1 + (math.random()*0.1)),
		vely=math.random()*-0.6,
		tint={r=110 + math.random(-10, 20), g=89 + math.random(-10, 25), b=73 + math.random(-5, 25)},
		gravity=0.02,
		fricx=0.98,
		fricy=1
		})
	end
end